@@ -15,7 +15,7 @@ from fontTools.afmLib import AFM  # type: ignore [import]
 from fontTools.agl import toUnicode  # type: ignore [import]
 from fontTools.cffLib import CFFFontSet, TopDict  # type: ignore [import]
 
-from borb.io.read.types import Decimal as pDecimal
+from borb.io.read.types import Decimal as bDecimal
 from borb.io.read.types import Dictionary, Name
 from borb.pdf.canvas.font.adobe_standard_encoding import (
     adobe_standard_decode,
@@ -45,10 +45,12 @@ class Type1Font(SimpleFont):
     def _read_encoding_with_unclear_glyph_names(self):
 
         # figure out how many characters we'll need to calculate
-        assert "FirstChar" in self
-        assert isinstance(self["FirstChar"], pDecimal)
-        assert "LastChar" in self
-        assert isinstance(self["LastChar"], pDecimal)
+        # fmt: off
+        assert "FirstChar" in self, "Type1Font must have a /FirstChar entry"
+        assert isinstance(self["FirstChar"], bDecimal), "Type1Font must have a valid /FirstChar entry"
+        assert "LastChar" in self, "Type1Font must have a /LastChar entry"
+        assert isinstance(self["LastChar"], bDecimal), "Type1Font must have a valid /LastChar entry"
+        # fmt: on
         first_char: int = int(self["FirstChar"])
         last_char: int = int(self["LastChar"])
         self._character_identifier_to_unicode_lookup = {}
@@ -82,11 +84,11 @@ class Type1Font(SimpleFont):
             self._character_identifier_to_unicode_lookup
         )
         while i < len(self["Encoding"]["Differences"]):
-            assert isinstance(self["Encoding"]["Differences"][i], pDecimal)
+            assert isinstance(self["Encoding"]["Differences"][i], bDecimal)
             character_code: int = self["Encoding"]["Differences"][i]
             j = i + 1
             while j < len(self["Encoding"]["Differences"]) and not isinstance(
-                self["Encoding"]["Differences"][j], pDecimal
+                self["Encoding"]["Differences"][j], bDecimal
             ):
                 glyph_name: str = str(self["Encoding"]["Differences"][j])
                 cid: int = int(glyph_name[1:])
@@ -122,10 +124,12 @@ class Type1Font(SimpleFont):
             return
 
         # figure out how many characters we'll need to calculate
-        assert "FirstChar" in self
-        assert isinstance(self["FirstChar"], pDecimal)
-        assert "LastChar" in self
-        assert isinstance(self["LastChar"], pDecimal)
+        # fmt: off
+        assert "FirstChar" in self, "Type1Font must have a /FirstChar entry"
+        assert isinstance(self["FirstChar"], bDecimal), "Type1Font must have a valid /FirstChar entry"
+        assert "LastChar" in self, "Type1Font must have a /LastChar entry"
+        assert isinstance(self["LastChar"], bDecimal), "Type1Font must have a valid /LastChar entry"
+        # fmt: on
         first_char: int = int(self["FirstChar"])
         last_char: int = int(self["LastChar"])
         self._character_identifier_to_unicode_lookup = {}
@@ -171,11 +175,11 @@ class Type1Font(SimpleFont):
         j: int = 0
         i = 0
         while i < len(self["Encoding"]["Differences"]):
-            assert isinstance(self["Encoding"]["Differences"][i], pDecimal)
+            assert isinstance(self["Encoding"]["Differences"][i], bDecimal)
             character_code: int = self["Encoding"]["Differences"][i]
             j = i + 1
             while j < len(self["Encoding"]["Differences"]) and not isinstance(
-                self["Encoding"]["Differences"][j], pDecimal
+                self["Encoding"]["Differences"][j], bDecimal
             ):
                 glyph_name: str = str(self["Encoding"]["Differences"][j])
                 self._character_identifier_to_unicode_lookup[
@@ -193,8 +197,10 @@ class Type1Font(SimpleFont):
     def _read_to_unicode(self):
         if len(self._unicode_lookup_to_character_identifier) > 0:
             return
-        assert "ToUnicode" in self
-        assert "DecodedBytes" in self["ToUnicode"]
+        # fmt: off
+        assert "ToUnicode" in self, "Type1Font must have a /ToUnicode entry."
+        assert ("DecodedBytes" in self["ToUnicode"]), "Type1Font must have a valid /ToUnicode entry."
+        # fmt: on
         cmap_bytes: bytes = self["ToUnicode"]["DecodedBytes"]
         self._character_identifier_to_unicode_lookup = self._read_cmap(cmap_bytes)
         self._unicode_lookup_to_character_identifier: typing.Dict[str, int] = {
@@ -336,7 +342,7 @@ class Type1Font(SimpleFont):
         # default
         return None
 
-    def get_width(self, character_identifier: int) -> typing.Optional[pDecimal]:
+    def get_width(self, character_identifier: int) -> typing.Optional[bDecimal]:
         """
         This function returns the width (in text space) of a given character identifier.
         If this Font is unable to represent the glyph that corresponds to the character identifier,
@@ -348,14 +354,14 @@ class Type1Font(SimpleFont):
             return self["Widths"][character_identifier - first_char]
         return None
 
-    def get_ascent(self) -> pDecimal:
+    def get_ascent(self) -> bDecimal:
         """
         This function returns the maximum height above the baseline reached by glyphs in this font.
         The height of glyphs for accented characters shall be excluded.
         """
         return self["FontDescriptor"]["Ascent"]
 
-    def get_descent(self) -> pDecimal:
+    def get_descent(self) -> bDecimal:
         """
         This function returns the maximum depth below the baseline reached by glyphs in this font.
         The value shall be a negative number.
@@ -425,15 +431,15 @@ class StandardType1Font(Type1Font):
         if font_name is not None:
 
             font_name = StandardType1Font._canonical_name(font_name)
-            assert font_name is not None
+            assert font_name is not None, "font_name must be one of the 14 StandardType1Font names."
 
-            # assert whether AFM directory exists
+            # check whether AFM directory exists
             afm_directory: Path = Path(__file__).parent / "afm"
-            assert afm_directory.exists()
+            assert afm_directory.exists(), "AFM directory not found"
 
-            # assert whether AFM file exists
+            # check whether AFM file exists
             afm_file: Path = afm_directory / (font_name.lower() + ".afm")
-            assert afm_file.exists()
+            assert afm_file.exists(), "afm file not found"
 
             # build AFM datastructure
             self._afm: AFM = AFM(afm_file)
@@ -480,38 +486,38 @@ class StandardType1Font(Type1Font):
         """
         return self._unicode_lookup_to_character_identifier.get(unicode)
 
-    def get_width(self, character_identifier: int) -> typing.Optional[pDecimal]:
+    def get_width(self, character_identifier: int) -> typing.Optional[bDecimal]:
         """
         This function returns the width (in text space) of a given character identifier.
         If this Font is unable to represent the glyph that corresponds to the character identifier,
         this function returns None
         """
-        widths: typing.List[pDecimal] = [
-            pDecimal(v[1])
+        widths: typing.List[bDecimal] = [
+            bDecimal(v[1])
             for k, v in self._afm._chars.items()
             if v[0] == character_identifier
         ]
         if len(widths) == 1:
             return widths[0]
-        return pDecimal(0)
+        return bDecimal(0)
 
-    def get_ascent(self) -> pDecimal:
+    def get_ascent(self) -> bDecimal:
         """
         This function returns the maximum height above the baseline reached by glyphs in this font.
         The height of glyphs for accented characters shall be excluded.
         """
         if "Ascender" in self._afm._attrs:
-            return pDecimal(self._afm._attrs["Ascender"])
-        return pDecimal(0)
+            return bDecimal(self._afm._attrs["Ascender"])
+        return bDecimal(0)
 
-    def get_descent(self) -> pDecimal:
+    def get_descent(self) -> bDecimal:
         """
         This function returns the maximum depth below the baseline reached by glyphs in this font.
         The value shall be a negative number.
         """
         if "Descender" in self._afm._attrs:
-            return pDecimal(self._afm._attrs["Descender"])
-        return pDecimal(0)
+            return bDecimal(self._afm._attrs["Descender"])
+        return bDecimal(0)
 
     def _empty_copy(self) -> "Font":
         return StandardType1Font()
