@@ -24,12 +24,20 @@ class DropDownList(FormField):
 
     def __init__(
         self,
-        possible_values: typing.List[str],
-        font_size: Decimal = Decimal(12),
-        font_color: Color = HexColor("000000"),
-        value: str = "",
         default_value: str = "",
         field_name: typing.Optional[str] = None,
+        font_color: Color = HexColor("000000"),
+        font_size: Decimal = Decimal(12),
+        margin_bottom: typing.Optional[Decimal] = None,
+        margin_left: typing.Optional[Decimal] = None,
+        margin_right: typing.Optional[Decimal] = None,
+        margin_top: typing.Optional[Decimal] = None,
+        padding_bottom: Decimal = Decimal(0),
+        padding_left: Decimal = Decimal(0),
+        padding_right: Decimal = Decimal(0),
+        padding_top: Decimal = Decimal(0),
+        possible_values: typing.List[str] = [],
+        value: str = "",
     ):
         super(DropDownList, self).__init__()
         assert font_size >= 0
@@ -46,6 +54,9 @@ class DropDownList(FormField):
         if self._widget_dictionary is not None:
             return
 
+        if "XRef" not in page.get_root():  # type: ignore [attr-defined]
+            return
+
         # init page and font resources
         assert self._font_size is not None
         font_resource_name: Name = self._get_font_resource_name(
@@ -60,7 +71,7 @@ class DropDownList(FormField):
         widget_normal_appearance: Stream = Stream()
         widget_normal_appearance[Name("Type")] = Name("XObject")
         widget_normal_appearance[Name("Subtype")] = Name("Form")
-        widget_normal_appearance[Name("BBox")] = List().set_can_be_referenced(False)  # type: ignore [attr-defined]
+        widget_normal_appearance[Name("BBox")] = List().set_is_inline(True)  # type: ignore [attr-defined]
         widget_normal_appearance["BBox"].append(bDecimal(0))
         widget_normal_appearance["BBox"].append(bDecimal(0))
         widget_normal_appearance["BBox"].append(bDecimal(layout_box.width))
@@ -88,7 +99,7 @@ class DropDownList(FormField):
         self._widget_dictionary[Name("Type")] = Name("Annot")
         self._widget_dictionary[Name("Subtype")] = Name("Widget")
         self._widget_dictionary[Name("F")] = bDecimal(4)
-        self._widget_dictionary[Name("Rect")] = List().set_can_be_referenced(False)  # type: ignore [attr-defined]
+        self._widget_dictionary[Name("Rect")] = List().set_is_inline(True)  # type: ignore [attr-defined]
         self._widget_dictionary["Rect"].append(bDecimal(layout_box.x))
         self._widget_dictionary["Rect"].append(
             bDecimal(layout_box.y + layout_box.height - self._font_size - 2)
@@ -154,15 +165,15 @@ class DropDownList(FormField):
         self._init_widget_dictionary(page, layout_rect)
 
         # set location
-        assert self._widget_dictionary is not None
-        self._widget_dictionary["AP"]["N"]["BBox"][2] = bDecimal(layout_box.width)
-        self._widget_dictionary["AP"]["N"]["BBox"][3] = bDecimal(self._font_size)
-        self._widget_dictionary["Rect"][0] = bDecimal(layout_box.x)
-        self._widget_dictionary["Rect"][1] = bDecimal(
-            layout_box.y + layout_box.height - self._font_size
-        )
-        self._widget_dictionary["Rect"][2] = bDecimal(layout_box.x + layout_box.width)
-        self._widget_dictionary["Rect"][3] = bDecimal(layout_box.y + layout_box.height)
+        # fmt: off
+        if self._widget_dictionary is not None:
+            self._widget_dictionary["AP"]["N"]["BBox"][2] = bDecimal(layout_box.width)
+            self._widget_dictionary["AP"]["N"]["BBox"][3] = bDecimal(self._font_size)
+            self._widget_dictionary["Rect"][0] = bDecimal(layout_box.x)
+            self._widget_dictionary["Rect"][1] = bDecimal(layout_box.y + layout_box.height - self._font_size)
+            self._widget_dictionary["Rect"][2] = bDecimal(layout_box.x + layout_box.width)
+            self._widget_dictionary["Rect"][3] = bDecimal(layout_box.y + layout_box.height)
+        # fmt: on
 
         # return Rectangle
         return layout_rect
