@@ -11,10 +11,11 @@ from enum import Enum
 import barcode  # type: ignore [import]
 import qrcode  # type: ignore [import]
 from barcode.writer import ImageWriter as BarcodeImageWriter  # type: ignore [import]
-from borb.pdf.canvas.color.color import Color, HexColor, X11Color
+from PIL import Image as PILImage  # type: ignore [import]
+
+from borb.pdf.canvas.color.color import Color, HexColor
 from borb.pdf.canvas.layout.image.image import Image
 from borb.pdf.canvas.layout.layout_element import Alignment
-from PIL import Image as PILImage  # type: ignore [import]
 
 
 class BarcodeType(Enum):
@@ -84,17 +85,35 @@ class Barcode(Image):
         self,
         data: str,
         type: BarcodeType,
-        width: typing.Optional[Decimal] = None,
-        height: typing.Optional[Decimal] = None,
         stroke_color: Color = HexColor("000000"),
         fill_color: Color = HexColor("ffffff"),
+        border_bottom: bool = False,
+        border_color: Color = HexColor("000000"),
+        border_left: bool = False,
+        border_radius_bottom_left: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
+        border_right: bool = False,
+        border_top: bool = False,
+        border_width: Decimal = Decimal(1),
+        height: typing.Optional[Decimal] = None,
         horizontal_alignment: Alignment = Alignment.LEFT,
+        margin_bottom: typing.Optional[Decimal] = None,
+        margin_left: typing.Optional[Decimal] = None,
+        margin_right: typing.Optional[Decimal] = None,
+        margin_top: typing.Optional[Decimal] = None,
+        padding_bottom: Decimal = Decimal(0),
+        padding_left: Decimal = Decimal(0),
+        padding_right: Decimal = Decimal(0),
+        padding_top: Decimal = Decimal(0),
         vertical_alignment: Alignment = Alignment.TOP,
+        width: typing.Optional[Decimal] = None,
     ):
-        self._data = data
-        self._type = type
-        self._stroke_color = stroke_color
-        self._fill_color = fill_color
+        self._data: str = data
+        self._type: BarcodeType = type
+        self._stroke_color: Color = stroke_color
+        self._fill_color: Color = fill_color
 
         assert stroke_color != fill_color
 
@@ -108,9 +127,28 @@ class Barcode(Image):
             image,
             width=width,
             height=height,
+            border_bottom=border_bottom,
+            border_color=border_color,
+            border_left=border_left,
+            border_radius_bottom_left=border_radius_bottom_left,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_right=border_right,
+            border_top=border_top,
+            border_width=border_width,
             horizontal_alignment=horizontal_alignment,
+            margin_bottom=margin_bottom if margin_bottom is not None else Decimal(5),
+            margin_left=margin_left if margin_left is not None else Decimal(5),
+            margin_right=margin_right if margin_right is not None else Decimal(5),
+            margin_top=margin_top if margin_top is not None else Decimal(5),
+            padding_bottom=padding_bottom,
+            padding_left=padding_left,
+            padding_right=padding_right,
+            padding_top=padding_top,
             vertical_alignment=vertical_alignment,
         )
+        self._background_color = fill_color
 
     def _generate_image_except_qr_code(self, data: str, type: BarcodeType):
         # generate image using barcode library
