@@ -9,7 +9,7 @@ from decimal import Decimal
 
 from borb.pdf.canvas.color.color import Color, HexColor, X11Color
 from borb.pdf.canvas.geometry.rectangle import Rectangle
-from borb.pdf.canvas.layout.layout_element import LayoutElement
+from borb.pdf.canvas.layout.layout_element import LayoutElement, Alignment
 from borb.pdf.canvas.layout.text.chunk_of_text import ChunkOfText
 from borb.pdf.page.page import Page
 
@@ -21,40 +21,51 @@ class List(LayoutElement):
 
     def __init__(
         self,
-        border_top: bool = False,
-        border_right: bool = False,
+        background_color: typing.Optional[Color] = None,
         border_bottom: bool = False,
-        border_left: bool = False,
         border_color: Color = HexColor("000000"),
+        border_left: bool = False,
+        border_radius_bottom_left: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
+        border_right: bool = False,
+        border_top: bool = False,
         border_width: Decimal = Decimal(1),
-        padding_top: Decimal = Decimal(0),
-        padding_right: Decimal = Decimal(0),
-        padding_bottom: Decimal = Decimal(0),
-        padding_left: Decimal = Decimal(0),
-        margin_top: typing.Optional[Decimal] = None,
-        margin_right: typing.Optional[Decimal] = None,
+        horizontal_alignment: Alignment = Alignment.LEFT,
         margin_bottom: typing.Optional[Decimal] = None,
         margin_left: typing.Optional[Decimal] = None,
-        background_color: typing.Optional[Color] = None,
-        parent: typing.Optional["LayoutElement"] = None,
+        margin_right: typing.Optional[Decimal] = None,
+        margin_top: typing.Optional[Decimal] = None,
+        padding_bottom: Decimal = Decimal(0),
+        padding_left: Decimal = Decimal(0),
+        padding_right: Decimal = Decimal(0),
+        padding_top: Decimal = Decimal(0),
+        vertical_alignment: Alignment = Alignment.TOP,
     ):
         super(List, self).__init__(
-            border_top=border_top,
-            border_right=border_right,
+            background_color=background_color,
             border_bottom=border_bottom,
-            border_left=border_left,
             border_color=border_color,
+            border_left=border_left,
+            border_radius_bottom_left=border_radius_bottom_left,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_right=border_right,
+            border_top=border_top,
             border_width=border_width,
-            padding_top=padding_top,
-            padding_right=padding_right,
-            padding_bottom=padding_bottom,
-            padding_left=padding_left,
-            margin_top=margin_top,
-            margin_right=margin_right,
+            font_size=Decimal(12),
+            horizontal_alignment=horizontal_alignment,
             margin_bottom=margin_bottom,
             margin_left=margin_left,
-            background_color=background_color,
-            parent=parent,
+            margin_right=margin_right,
+            margin_top=margin_top,
+            padding_bottom=padding_bottom,
+            padding_left=padding_left,
+            padding_right=padding_right,
+            padding_top=padding_top,
+            vertical_alignment=vertical_alignment,
         )
         self._items: typing.List[LayoutElement] = []
 
