@@ -10,13 +10,13 @@ import typing
 import zlib
 from decimal import Decimal
 
-from borb.io.read.types import Decimal as pDecimal
+from borb.io.read.types import Decimal as bDecimal
 from borb.io.read.types import Name
 from borb.pdf.canvas.geometry.rectangle import Rectangle
 from borb.pdf.canvas.layout.layout_element import LayoutElement
 from borb.pdf.canvas.layout.page_layout.page_layout import PageLayout
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 
 
@@ -35,6 +35,7 @@ class MultiColumnLayout(PageLayout):
         vertical_margin: typing.Optional[Decimal] = None,
         fixed_paragraph_spacing: typing.Optional[Decimal] = None,
         multiplied_paragraph_spacing: typing.Optional[Decimal] = None,
+        multiplied_inter_column_spacing: typing.Optional[Decimal] = None,
     ):
         super().__init__(page)
 
@@ -42,19 +43,18 @@ class MultiColumnLayout(PageLayout):
         # fmt: off
         self._page_width: typing.Optional[Decimal] = self._page.get_page_info().get_width()
         self._page_height: typing.Optional[Decimal] = self._page.get_page_info().get_height()
-        assert self._page_width
-        assert self._page_height
+        assert self._page_width, "page.get_width() must be defined for MultiColumnLayout to work"
+        assert self._page_height, "page.get_height() must be defined for MultiColumnLayout to work"
         # fmt: on
 
         # paragraph spacing
         if fixed_paragraph_spacing is None and multiplied_paragraph_spacing is None:
             multiplied_paragraph_spacing = Decimal(1.2)
-        assert (
-            fixed_paragraph_spacing is not None
-            or multiplied_paragraph_spacing is not None
-        )
-        assert fixed_paragraph_spacing is None or fixed_paragraph_spacing >= 0
-        assert multiplied_paragraph_spacing is None or multiplied_paragraph_spacing >= 0
+        # fmt: off
+        assert (fixed_paragraph_spacing is not None or multiplied_paragraph_spacing is not None), "fixed_paragraph_spacing or multiplied_paragraph_spacing must be defined for MultiColumnLayout to work"
+        assert fixed_paragraph_spacing is None or fixed_paragraph_spacing >= 0, "fixed_paragraph_spacing must be a non-negative number"
+        assert multiplied_paragraph_spacing is None or multiplied_paragraph_spacing >= 0, "multiplied_paragraph_spacing must be a non-negative number"
+        # fmt: on
         self._fixed_paragraph_spacing: typing.Optional[
             Decimal
         ] = fixed_paragraph_spacing
@@ -77,12 +77,19 @@ class MultiColumnLayout(PageLayout):
             self._vertical_margin = vertical_margin
 
         # inter-column margin
-        self._inter_column_margin = self._page_width * Decimal(0.05)
+        # fmt: off
+        if multiplied_inter_column_spacing is None:
+            multiplied_inter_column_spacing = Decimal(0.05)
+        assert multiplied_inter_column_spacing >= Decimal(0), "multiplied_inter_column_spacing must be a non-negative number"
+        assert multiplied_inter_column_spacing * (number_of_columns - 1) < Decimal(1), "multiplied_inter_column_spacing must not be larger than 1"
+        self._inter_column_spacing = self._page_width * multiplied_inter_column_spacing
+        # fmt: on
+
         self._number_of_columns = Decimal(number_of_columns)
         self._column_width = (
             self._page_width
             - Decimal(2) * self._horizontal_margin
-            - Decimal(number_of_columns - 1) * self._inter_column_margin
+            - Decimal(number_of_columns - 1) * self._inter_column_spacing
         ) / Decimal(number_of_columns)
 
         # previous element information
@@ -178,7 +185,7 @@ class MultiColumnLayout(PageLayout):
 
         # fmt: off
         next_available_rect: Rectangle = Rectangle(
-            self._horizontal_margin + self._current_column_index * (self._column_width + self._inter_column_margin) + layout_element.get_margin_left(),
+            self._horizontal_margin + self._current_column_index * (self._column_width + self._inter_column_spacing) + layout_element.get_margin_left(),
             self._vertical_margin + layout_element.get_margin_bottom(),
             self._column_width - layout_element.get_margin_right() - layout_element.get_margin_left(),
             available_height
@@ -216,7 +223,7 @@ class MultiColumnLayout(PageLayout):
             content_stream[Name("Bytes")] = zlib.compress(
                 content_stream["DecodedBytes"], 9
             )
-            content_stream[Name("Length")] = pDecimal(len(content_stream["Bytes"]))
+            content_stream[Name("Length")] = bDecimal(len(content_stream["Bytes"]))
             self.switch_to_next_column()
             return self.add(layout_element)
 
