@@ -9,10 +9,10 @@ of <table> elements in HTML
 import typing
 import zlib
 from decimal import Decimal
-from math import ceil, floor
+from math import floor
 
 from borb.io.read.types import Name
-from borb.pdf.canvas.color.color import Color, HexColor, X11Color
+from borb.pdf.canvas.color.color import Color, HexColor
 from borb.pdf.canvas.geometry.rectangle import Rectangle
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.table.table import Table, TableCell
@@ -35,6 +35,10 @@ class FlexibleColumnWidthTable(Table):
         border_right: bool = False,
         border_bottom: bool = False,
         border_left: bool = False,
+        border_radius_bottom_left: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
         border_color: Color = HexColor("000000"),
         border_width: Decimal = Decimal(1),
         padding_top: Decimal = Decimal(0),
@@ -52,22 +56,26 @@ class FlexibleColumnWidthTable(Table):
         super(FlexibleColumnWidthTable, self).__init__(
             number_of_rows=number_of_rows,
             number_of_columns=number_of_columns,
-            border_top=border_top,
-            border_right=border_right,
+            background_color=background_color,
             border_bottom=border_bottom,
-            border_left=border_left,
             border_color=border_color,
+            border_left=border_left,
+            border_radius_bottom_left=border_radius_bottom_left,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_right=border_right,
+            border_top=border_top,
             border_width=border_width,
-            padding_top=padding_top,
-            padding_right=padding_right,
+            horizontal_alignment=horizontal_alignment,
+            margin_bottom=margin_bottom if margin_bottom is not None else Decimal(5),
+            margin_left=margin_left if margin_left is not None else Decimal(5),
+            margin_right=margin_right if margin_right is not None else Decimal(5),
+            margin_top=margin_top if margin_top is not None else Decimal(5),
             padding_bottom=padding_bottom,
             padding_left=padding_left,
-            margin_top=margin_top,
-            margin_right=margin_right,
-            margin_bottom=margin_bottom,
-            margin_left=margin_left,
-            background_color=background_color,
-            horizontal_alignment=horizontal_alignment,
+            padding_right=padding_right,
+            padding_top=padding_top,
             vertical_alignment=vertical_alignment,
         )
 
