@@ -12,6 +12,7 @@ from borb.pdf.canvas.color.color import Color, HexColor
 from borb.pdf.canvas.font.font import Font
 from borb.pdf.canvas.font.glyph_line import GlyphLine
 from borb.pdf.canvas.font.simple_font.font_type_1 import StandardType1Font
+from borb.pdf.canvas.font.simple_font.true_type_font import TrueTypeFont
 from borb.pdf.canvas.geometry.rectangle import Rectangle
 from borb.pdf.canvas.layout.layout_element import Alignment, LayoutElement
 from borb.pdf.page.page import Page
@@ -32,6 +33,10 @@ class ChunkOfText(LayoutElement):
         border_right: bool = False,
         border_bottom: bool = False,
         border_left: bool = False,
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_bottom_left: Decimal = Decimal(0),
         border_color: Color = HexColor("000000"),
         border_width: Decimal = Decimal(1),
         padding_top: Decimal = Decimal(0),
@@ -44,8 +49,9 @@ class ChunkOfText(LayoutElement):
         margin_left: typing.Optional[Decimal] = None,
         vertical_alignment: Alignment = Alignment.TOP,
         horizontal_alignment: Alignment = Alignment.LEFT,
+        fixed_leading: typing.Optional[Decimal] = None,
+        multiplied_leading: typing.Optional[Decimal] = None,
         background_color: typing.Optional[Color] = None,
-        parent: typing.Optional["LayoutElement"] = None,
     ):
         super().__init__(
             font_size=font_size,
@@ -53,6 +59,10 @@ class ChunkOfText(LayoutElement):
             border_right=border_right,
             border_bottom=border_bottom,
             border_left=border_left,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_bottom_left=border_radius_bottom_left,
             border_color=border_color,
             border_width=border_width,
             padding_top=padding_top,
@@ -66,9 +76,10 @@ class ChunkOfText(LayoutElement):
             vertical_alignment=vertical_alignment,
             horizontal_alignment=horizontal_alignment,
             background_color=background_color,
-            parent=parent,
         )
         self._text = text
+
+        # font information
         if isinstance(font, str):
             self._font: Font = StandardType1Font(font)
             assert self._font
@@ -76,6 +87,15 @@ class ChunkOfText(LayoutElement):
             self._font = font
         self._font_color = font_color
 
+        # leading
+        if fixed_leading is None and multiplied_leading is None:
+            multiplied_leading = Decimal(1.2)
+        assert fixed_leading is not None or multiplied_leading is not None
+        assert fixed_leading is None or fixed_leading > 0
+        assert multiplied_leading is None or multiplied_leading > 0
+        self._multiplied_leading: typing.Optional[Decimal] = multiplied_leading
+        self._fixed_leading: typing.Optional[Decimal] = fixed_leading
+
     def get_text(self) -> str:
         """
         This function returns the text of this LayoutElement
@@ -114,11 +134,13 @@ class ChunkOfText(LayoutElement):
 
     def _write_text_bytes(self) -> str:
         hex_mode: bool = False
+        # check glyphs
         for c in self._text:
             if ord(c) != self._font.unicode_to_character_identifier(c):
                 hex_mode = True
                 break
-        if hex_mode:
+        # delegate
+        if hex_mode or isinstance(self._font, TrueTypeFont):
             return self._write_text_bytes_in_hex()
         else:
             return self._write_text_bytes_in_ascii()
@@ -178,7 +200,15 @@ class ChunkOfText(LayoutElement):
     def _do_layout_without_padding(self, page: Page, bounding_box: Rectangle):
         assert self._font
         rgb_color = self._font_color.to_rgb()
+
+        # line height
         assert self._font_size is not None
+        line_height: Decimal = self._font_size
+        if self._multiplied_leading is not None:
+            line_height *= self._multiplied_leading
+        if self._fixed_leading is not None:
+            line_height += self._fixed_leading
+
         content = """
             q
             BT
@@ -197,21 +227,19 @@ class ChunkOfText(LayoutElement):
             float(self._font_size),  # Tm
             float(self._font_size),  # Tm
             float(bounding_box.x),  # Tm
-            float(bounding_box.y + bounding_box.height - self._font_size),  # Tm
+            float(bounding_box.y + bounding_box.height - line_height),  # Tm
             self._write_text_bytes(),  # Tj
         )
         self._append_to_content_stream(page, content)
-        encoded_bytes: bytes = [
-            self._font.unicode_to_character_identifier(c) or 0 for c in self._text
-        ]
+
+        # fmt: off
         layout_rect = Rectangle(
             bounding_box.x,
-            bounding_box.y + bounding_box.height - self._font_size,
-            GlyphLine(
-                encoded_bytes, self._font, self._font_size
-            ).get_width_in_text_space(),
-            self._font_size,
+            bounding_box.y + bounding_box.height - line_height,
+            GlyphLine.from_str(self._text, self._font, self._font_size).get_width_in_text_space(),
+            line_height,
         )
+        # fmt: on
 
         # set bounding box
         self.set_bounding_box(layout_rect)
