@@ -40,6 +40,10 @@ class Span(Paragraph):
         border_right: bool = False,
         border_bottom: bool = False,
         border_left: bool = False,
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_bottom_left: Decimal = Decimal(0),
         border_color: Color = HexColor("000000"),
         border_width: Decimal = Decimal(1),
         padding_top: Decimal = Decimal(0),
@@ -50,42 +54,38 @@ class Span(Paragraph):
         margin_right: typing.Optional[Decimal] = None,
         margin_bottom: typing.Optional[Decimal] = None,
         margin_left: typing.Optional[Decimal] = None,
-        line_height: Decimal = Decimal(1),
+        fixed_leading: typing.Optional[Decimal] = None,
+        multiplied_leading: typing.Optional[Decimal] = None,
         background_color: typing.Optional[Color] = None,
-        parent: typing.Optional["LayoutElement"] = None,  # type: ignore [name-defined]
     ):
-
-        # background color
-        self._background_color: typing.Optional[Color] = background_color
-
-        # borders
-        self._border_color: Color = border_color
-        self._border_width: Decimal = border_width
-        self._border_top: bool = border_top
-        self._border_right: bool = border_right
-        self._border_bottom: bool = border_bottom
-        self._border_left: bool = border_left
-
-        # alignment
-        self._horizontal_alignment = horizontal_alignment
-        self._vertical_alignment = vertical_alignment
-
-        # padding
-        self._padding_top: Decimal = padding_top
-        self._padding_right: Decimal = padding_right
-        self._padding_bottom: Decimal = padding_bottom
-        self._padding_left: Decimal = padding_left
-
-        # margin
-        self._margin_top: typing.Optional[Decimal] = margin_top
-        self._margin_right: typing.Optional[Decimal] = margin_right
-        self._margin_bottom: typing.Optional[Decimal] = margin_bottom
-        self._margin_left: typing.Optional[Decimal] = margin_left
-
-        # leading
-        self._font_size: typing.Optional[Decimal] = None
-        assert line_height >= Decimal(1)
-        self._line_height: Decimal = line_height
+        super(Span, self).__init__(
+            text="",
+            vertical_alignment=vertical_alignment,
+            horizontal_alignment=horizontal_alignment,
+            border_top=border_top,
+            border_right=border_right,
+            border_bottom=border_bottom,
+            border_left=border_left,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_bottom_left=border_radius_bottom_left,
+            border_color=border_color,
+            border_width=border_width,
+            padding_top=padding_top,
+            padding_right=padding_right,
+            padding_bottom=padding_bottom,
+            padding_left=padding_left,
+            margin_top=margin_top,
+            margin_right=margin_right,
+            margin_bottom=margin_bottom,
+            margin_left=margin_left,
+            multiplied_leading=multiplied_leading,
+            fixed_leading=fixed_leading,
+            background_color=background_color,
+        )
+        # modify
+        self._font_size = None
 
         # store chunks
         self._chunks_of_text: typing.List[ChunkOfText] = []
@@ -208,11 +208,18 @@ class Span(Paragraph):
                 max_x = max(r.x + r.width, max_x)
                 max_y = max(r.y + r.height, max_y)
 
-            # update line_y
-            line_y -= (
-                max([x.get_bounding_box().get_height() for x in line_of_chunks])  # type: ignore [union-attr]
-                * self._line_height
+            # line height
+            max_height: Decimal = max(
+                [x.get_bounding_box().get_height() for x in line_of_chunks]
             )
+            line_height: Decimal = max_height
+            if self._fixed_leading is not None:
+                line_height += self._fixed_leading
+            if self._multiplied_leading is not None:
+                line_height *= self._multiplied_leading
+
+            # update line_y
+            line_y -= line_height
 
         layout_rect = Rectangle(min_x, min_y, max_x - min_x, max_y - min_y)
 
@@ -239,6 +246,10 @@ class HeterogeneousParagraph(Span):
         border_right: bool = False,
         border_bottom: bool = False,
         border_left: bool = False,
+        border_radius_top_left: Decimal = Decimal(0),
+        border_radius_top_right: Decimal = Decimal(0),
+        border_radius_bottom_right: Decimal = Decimal(0),
+        border_radius_bottom_left: Decimal = Decimal(0),
         border_color: Color = HexColor("000000"),
         border_width: Decimal = Decimal(1),
         padding_top: Decimal = Decimal(0),
@@ -249,9 +260,9 @@ class HeterogeneousParagraph(Span):
         margin_right: typing.Optional[Decimal] = None,
         margin_bottom: typing.Optional[Decimal] = None,
         margin_left: typing.Optional[Decimal] = None,
-        line_height: Decimal = Decimal(1),
+        fixed_leading: typing.Optional[Decimal] = None,
+        multiplied_leading: typing.Optional[Decimal] = None,
         background_color: typing.Optional[Color] = None,
-        parent: typing.Optional["LayoutElement"] = None,  # type: ignore [name-defined]
     ):
         super(HeterogeneousParagraph, self).__init__(
             chunks_of_text=chunks_of_text,
@@ -261,6 +272,10 @@ class HeterogeneousParagraph(Span):
             border_right=border_right,
             border_bottom=border_bottom,
             border_left=border_left,
+            border_radius_top_left=border_radius_top_left,
+            border_radius_top_right=border_radius_top_right,
+            border_radius_bottom_right=border_radius_bottom_right,
+            border_radius_bottom_left=border_radius_bottom_left,
             border_color=border_color,
             border_width=border_width,
             padding_top=padding_top,
@@ -271,9 +286,9 @@ class HeterogeneousParagraph(Span):
             margin_right=margin_right,
             margin_bottom=margin_bottom,
             margin_left=margin_left,
-            line_height=line_height,
+            fixed_leading=fixed_leading,
+            multiplied_leading=multiplied_leading,
             background_color=background_color,
-            parent=parent,
         )
 
     def add(
