@@ -4,8 +4,8 @@
 """
 Same as RG but used for nonstroking operations.
 """
+import typing
 from decimal import Decimal
-from typing import List
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.color.color import RGBColor
@@ -20,7 +20,12 @@ class SetRGBNonStroking(CanvasOperator):
     def __init__(self):
         super().__init__("rg", 3)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the rg operator
         """
