@@ -7,8 +7,8 @@ space; see 8.6.5.6, "Default Colour Spaces") and set the colour to use for
 stroking operations. Each operand shall be a number between 0.0
 (minimum intensity) and 1.0 (maximum intensity).
 """
+import typing
 from decimal import Decimal
-from typing import List
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.color.color import RGBColor
@@ -26,7 +26,12 @@ class SetRGBStroking(CanvasOperator):
     def __init__(self):
         super().__init__("RG", 3)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the RG operator
         """
