@@ -6,7 +6,8 @@
 their operands) shall be ignored without error until the balancing EX operator
 is encountered.
 """
-from typing import List
+
+import typing
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -22,7 +23,12 @@ class EndCompatibilitySection(CanvasOperator):
     def __init__(self):
         super().__init__("EX", 0)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the EX operator
         """
