@@ -4,7 +4,8 @@
 """
 End a marked-content sequence begun by a BMC or BDC operator.
 """
-from typing import List
+
+import typing
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -18,7 +19,12 @@ class EndMarkedContent(CanvasOperator):
     def __init__(self):
         super().__init__("EMC", 0)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the EMC operator
         """
