@@ -4,7 +4,8 @@
 """
 Stroke the path.
 """
-from typing import List
+
+import typing
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.event.line_render_event import LineRenderEvent
@@ -19,7 +20,12 @@ class StrokePath(CanvasOperator):
     def __init__(self):
         super().__init__("S", 0)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the S operator
         """
@@ -29,8 +35,9 @@ class StrokePath(CanvasOperator):
         gs = canvas.graphics_state
 
         # notify listeners
-        for l in gs.path:
-            canvas._event_occurred(LineRenderEvent(gs, l))
+        for el in event_listeners:
+            for l in gs.path:
+                el._event_occurred(LineRenderEvent(gs, l))
 
         # clear path
         gs.path = []
