@@ -6,7 +6,7 @@ Save the current graphics state on the graphics state stack (see
 8.4.2, "Graphics State Stack").
 """
 import copy
-from typing import List
+import typing
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -21,7 +21,12 @@ class PushGraphicsState(CanvasOperator):
     def __init__(self):
         super().__init__("q", 0)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the q operator
         """
