@@ -4,7 +4,8 @@
 """
 End a text object, discarding the text matrix.
 """
-from typing import List
+
+import typing
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.event.end_text_event import EndTextEvent
@@ -19,11 +20,17 @@ class EndTextObject(CanvasOperator):
     def __init__(self):
         super().__init__("ET", 0)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the ET operator
         """
         canvas = canvas_stream_processor.get_canvas()
         canvas.graphics_state.text_matrix = None
         canvas.graphics_state.text_line_matrix = None
-        canvas._event_occurred(EndTextEvent())
+        for l in event_listeners:
+            l._event_occurred(EndTextEvent())
