@@ -6,8 +6,8 @@ Set the text leading, T l , to leading, which shall be a number expressed in
 unscaled text space units. Text leading shall be used only by the T*, ', and
 " operators. Initial value: 0.
 """
+import typing
 from decimal import Decimal
-from typing import List
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -23,7 +23,12 @@ class SetTextLeading(CanvasOperator):
     def __init__(self):
         super().__init__("TL", 1)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the TL operator
         """
