@@ -5,8 +5,8 @@
 Set the text rise, T rise , to rise, which shall be a number expressed in
 unscaled text space units. Initial value: 0.
 """
+import typing
 from decimal import Decimal
-from typing import List
 
 from borb.io.read.types import AnyPDFType
 from borb.pdf.canvas.operator.canvas_operator import CanvasOperator
@@ -21,7 +21,12 @@ class SetTextRise(CanvasOperator):
     def __init__(self):
         super().__init__("Ts", 1)
 
-    def invoke(self, canvas_stream_processor: "CanvasStreamProcessor", operands: List[AnyPDFType] = []) -> None:  # type: ignore [name-defined]
+    def invoke(
+        self,
+        canvas_stream_processor: "CanvasStreamProcessor",  # type: ignore [name-defined]
+        operands: typing.List[AnyPDFType] = [],
+        event_listeners: typing.List["EventListener"] = [],  # type: ignore [name-defined]
+    ) -> None:
         """
         Invoke the Ts operator
         """
