@@ -7,16 +7,16 @@ from pathlib import Path
 from borb.pdf.canvas.color.color import HexColor, HSVColor, Color
 from borb.pdf.canvas.color.pantone import Pantone
 from borb.pdf.canvas.geometry.rectangle import Rectangle
-from borb.pdf.canvas.layout.image.shape import Shape
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.page_layout.page_layout import PageLayout
+from borb.pdf.canvas.layout.shape.shape import Shape
 from borb.pdf.canvas.layout.table.fixed_column_width_table import FixedColumnWidthTable
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
 from borb.pdf.canvas.line_art.line_art_factory import LineArtFactory
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestAnalogousColorScheme(unittest.TestCase):
@@ -80,9 +80,10 @@ class TestAnalogousColorScheme(unittest.TestCase):
         l.add(t)
 
         # write
-        file = self.output_dir / "output.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, d)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
