@@ -14,9 +14,10 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import check_pdf_using_validator
 
 
 class TestWrite3DDensityChart(unittest.TestCase):
@@ -91,11 +92,10 @@ class TestWrite3DDensityChart(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
-
-        return True
+        check_pdf_using_validator(out_file)
 
 
 if __name__ == "__main__":
