@@ -13,10 +13,10 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteDropDownList(unittest.TestCase):
@@ -60,9 +60,10 @@ class TestWriteDropDownList(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output_001.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_write_drop_down_using_layout_manager(self):
 
@@ -99,11 +100,12 @@ class TestWriteDropDownList(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output_002.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
 
-        compare_visually_to_ground_truth(file)
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
 
 
 if __name__ == "__main__":
