@@ -15,9 +15,10 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteTextArea(unittest.TestCase):
@@ -67,10 +68,14 @@ class TestWriteTextArea(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output_001.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
 
+        # compare visually
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
+
     def test_write_text_field_using_layout_manager(self):
 
         # create empty document
@@ -124,10 +129,14 @@ class TestWriteTextArea(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output_002.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
 
+        # compare visually
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
+
     def test_check_acroform_present(self):
 
         doc: typing.Optional[Document] = None
