@@ -12,10 +12,10 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestModifyImage(unittest.TestCase):
@@ -88,9 +88,10 @@ class TestModifyImage(unittest.TestCase):
         )
 
         # write
-        file = self.output_dir / "output_001.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_modify_image_in_document(self):
 
@@ -110,12 +111,13 @@ class TestModifyImage(unittest.TestCase):
                 self._modify_image(v)
 
         # write
-        file = self.output_dir / "output_002.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, doc)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output_002.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
 
 
 if __name__ == "__main__":
