@@ -4,18 +4,19 @@ from pathlib import Path
 
 from borb.io.read.types import Decimal
 from borb.pdf.canvas.color.color import HexColor
-from borb.pdf.canvas.layout.image.shape import Shape
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
+from borb.pdf.canvas.layout.shape.shape import Shape
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.table.table import TableCell
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
 from borb.pdf.canvas.line_art.blob_factory import BlobFactory
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import check_pdf_using_validator
 
 
 class TestWriteBlobs(unittest.TestCase):
@@ -87,5 +88,9 @@ class TestWriteBlobs(unittest.TestCase):
         with open(out_file, "wb") as in_file_handle:
             PDF.dumps(in_file_handle, pdf)
 
+        # attempt to read PDF again
         with open(out_file, "rb") as in_file_handle:
             PDF.loads(in_file_handle)
+
+        # check
+        check_pdf_using_validator(out_file)
