@@ -5,15 +5,17 @@ from pathlib import Path
 from borb.io.read.types import Decimal
 from borb.pdf.canvas.color.color import HexColor
 from borb.pdf.canvas.geometry.rectangle import Rectangle
+from borb.pdf.canvas.layout.annotation.square_annotation import SquareAnnotation
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteParagraphAlignment(unittest.TestCase):
@@ -104,9 +106,8 @@ class TestWriteParagraphAlignment(unittest.TestCase):
                     )
 
                     # add rectangle annotation
-                    page.append_square_annotation(
-                        stroke_color=HexColor("f1cd2e"),
-                        rectangle=bb,
+                    page.append_annotation(
+                        SquareAnnotation(bb, stroke_color=HexColor("f1cd2e"))
                     )
 
         # determine output location
@@ -115,3 +116,7 @@ class TestWriteParagraphAlignment(unittest.TestCase):
         # attempt to store PDF
         with open(out_file, "wb") as in_file_handle:
             PDF.dumps(in_file_handle, pdf)
+
+        # compare visually
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
