@@ -5,15 +5,17 @@ from pathlib import Path
 from borb.io.read.types import Decimal
 from borb.pdf.canvas.color.color import HexColor
 from borb.pdf.canvas.geometry.rectangle import Rectangle
+from borb.pdf.canvas.layout.annotation.square_annotation import SquareAnnotation
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteParagraphJustifiedCenter(unittest.TestCase):
@@ -69,7 +71,7 @@ class TestWriteParagraphJustifiedCenter(unittest.TestCase):
         # fmt: on
 
         # this is a quick and dirty way to draw a rectangle on the page
-        page.append_square_annotation(r, stroke_color=HexColor("f1cd2e"))
+        page.append_annotation(SquareAnnotation(r, stroke_color=HexColor("f1cd2e")))
 
         # add the paragraph to the page
         p.layout(page, r)
@@ -79,6 +81,10 @@ class TestWriteParagraphJustifiedCenter(unittest.TestCase):
         with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, doc)
 
+        # compare visually
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
+
     def test_write_document_002(self):
 
         # create output directory if it does not exist yet
@@ -132,7 +138,7 @@ class TestWriteParagraphJustifiedCenter(unittest.TestCase):
         # fmt: on
 
         # this is a quick and dirty way to draw a rectangle on the page
-        page.append_square_annotation(r, stroke_color=HexColor("f1cd2e"))
+        page.append_annotation(SquareAnnotation(r, stroke_color=HexColor("f1cd2e")))
 
         # add the paragraph to the page
         p.layout(page, r)
@@ -143,3 +149,7 @@ class TestWriteParagraphJustifiedCenter(unittest.TestCase):
         # attempt to store PDF
         with open(out_file, "wb") as in_file_handle:
             PDF.dumps(in_file_handle, pdf)
+
+        # compare visually
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
