@@ -9,10 +9,10 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Alignment, Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteTableWithNonBlackParagraphs(unittest.TestCase):
@@ -112,4 +112,5 @@ class TestWriteTableWithNonBlackParagraphs(unittest.TestCase):
             PDF.loads(in_file_handle)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
