@@ -1,10 +1,10 @@
 import unittest
 from pathlib import Path
 
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 
 class TestWriteEmptyDocument(unittest.TestCase):
@@ -35,12 +35,13 @@ class TestWriteEmptyDocument(unittest.TestCase):
         pdf.append_page(page)
 
         # write
-        file = self.output_dir / "output.pdf"
-        with open(file, "wb") as pdf_file_handle:
+        out_file = self.output_dir / "output.pdf"
+        with open(out_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
 
 
 if __name__ == "__main__":
