@@ -5,15 +5,17 @@ from pathlib import Path
 
 from borb.pdf.canvas.color.color import HexColor
 from borb.pdf.canvas.geometry.rectangle import Rectangle
+from borb.pdf.canvas.layout.annotation.polyline_annotation import PolylineAnnotation
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
 from borb.pdf.canvas.line_art.line_art_factory import LineArtFactory
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import check_pdf_using_validator
 
 
 class TestAddPolylineAnnotationUsingLineArtFactory(unittest.TestCase):
@@ -149,18 +151,22 @@ class TestAddPolylineAnnotationUsingLineArtFactory(unittest.TestCase):
 
         # add annotation
         for i, s in enumerate(shapes):
-            pdf.get_page(0).append_polyline_annotation(
-                points=s,
-                fill_color=colors[(i + 1) % len(colors)],
-                stroke_color=colors[i % len(colors)],
+            pdf.get_page(0).append_annotation(
+                PolylineAnnotation(
+                    points=s,
+                    fill_color=colors[(i + 1) % len(colors)],
+                    stroke_color=colors[i % len(colors)],
+                )
             )
 
         # attempt to store PDF
-        with open(self.output_dir / "output.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
 
         # attempt to re-open PDF
-        with open(self.output_dir / "output.pdf", "rb") as in_file_handle:
+        with open(out_file, "rb") as in_file_handle:
             doc = PDF.loads(in_file_handle)
 
-        return True
+        # check
+        check_pdf_using_validator(out_file)
