@@ -4,18 +4,20 @@ import unittest
 from decimal import Decimal
 from pathlib import Path
 
-from tests.test_util import compare_visually_to_ground_truth
-
 from borb.pdf.canvas.color.color import HexColor
 from borb.pdf.canvas.geometry.rectangle import Rectangle
+from borb.pdf.canvas.layout.annotation.remote_go_to_annotation import (
+    RemoteGoToAnnotation,
+)
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import FixedColumnWidthTable
 from borb.pdf.canvas.layout.text.chunk_of_text import ChunkOfText
 from borb.pdf.canvas.layout.text.chunks_of_text import HeterogeneousParagraph
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 unittest.TestLoader.sortTestMethodsUsing = None
 
@@ -72,20 +74,22 @@ class TestAddRemoteGoToAnnotation(unittest.TestCase):
             pdf.get_page(0), r
         )
 
-        pdf.get_page(0).append_remote_go_to_annotation(
-            rectangle=r, uri="https://www.borbpdf.com"
+        pdf.get_page(0).append_annotation(
+            RemoteGoToAnnotation(bounding_box=r, uri="https://www.borbpdf.com")
         )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_001.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
 
         # attempt to re-open PDF
-        with open(self.output_dir / "output_001.pdf", "rb") as in_file_handle:
+        with open(out_file, "rb") as in_file_handle:
             doc = PDF.loads(in_file_handle)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output_001.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
 
     def test_add_remote_go_to_annotation_by_regex(self):
 
@@ -123,17 +127,21 @@ class TestAddRemoteGoToAnnotation(unittest.TestCase):
         layout.add(hp)
 
         # add annotation
-        pdf.get_page(0).append_remote_go_to_annotation(
-            rectangle=chunks[4].get_bounding_box(), uri="https://www.borbpdf.com"
+        pdf.get_page(0).append_annotation(
+            RemoteGoToAnnotation(
+                bounding_box=chunks[4].get_bounding_box(), uri="https://www.borbpdf.com"
+            )
         )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_002.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
 
         # attempt to re-open PDF
-        with open(self.output_dir / "output_002.pdf", "rb") as in_file_handle:
+        with open(out_file, "rb") as in_file_handle:
             doc = PDF.loads(in_file_handle)
 
         # compare visually
-        compare_visually_to_ground_truth(self.output_dir / "output_002.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
