@@ -4,23 +4,25 @@ from decimal import Decimal
 from pathlib import Path
 
 from borb.pdf.canvas.color.color import HexColor
+from borb.pdf.canvas.layout.annotation.squiggly_annotation import SquigglyAnnotation
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
 from borb.toolkit.text.regular_expression_text_extraction import (
     RegularExpressionTextExtraction,
 )
+from tests.test_util import check_pdf_using_validator
 
 unittest.TestLoader.sortTestMethodsUsing = None
 
 
-class TestAddSquigglyAnnotation(unittest.TestCase):
+class TestAddSquiggleAnnotation(unittest.TestCase):
     def __init__(self, methodName="runTest"):
         super().__init__(methodName)
         # find output dir
@@ -77,8 +79,10 @@ class TestAddSquigglyAnnotation(unittest.TestCase):
         )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_001.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_add_squiggle_annotation(self):
 
@@ -90,12 +94,16 @@ class TestAddSquigglyAnnotation(unittest.TestCase):
 
         for m in l.get_matches_for_page(0):
             for bb in m.get_bounding_boxes():
-                doc.get_page(0).append_squiggly_annotation(
-                    bb,
-                    line_width=Decimal(2),
-                    stroke_color=HexColor("DE6449"),
+                doc.get_page(0).append_annotation(
+                    SquigglyAnnotation(
+                        bb,
+                        stroke_width=Decimal(2),
+                        stroke_color=HexColor("DE6449"),
+                    )
                 )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_002.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, doc)
+        check_pdf_using_validator(out_file)
