@@ -4,19 +4,20 @@ from decimal import Decimal
 from pathlib import Path
 
 from borb.pdf.canvas.color.color import HexColor
+from borb.pdf.canvas.layout.annotation.underline_annotation import UnderlineAnnotation
 from borb.pdf.canvas.layout.layout_element import Alignment
 from borb.pdf.canvas.layout.page_layout.multi_column_layout import SingleColumnLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
 from borb.toolkit.text.regular_expression_text_extraction import (
     RegularExpressionTextExtraction,
 )
-from tests.test_util import compare_visually_to_ground_truth
+from tests.test_util import compare_visually_to_ground_truth, check_pdf_using_validator
 
 unittest.TestLoader.sortTestMethodsUsing = None
 
@@ -78,8 +79,10 @@ class TestAddUnderlineAnnotation(unittest.TestCase):
         )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_001.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_add_underline_annotation(self):
 
@@ -91,13 +94,16 @@ class TestAddUnderlineAnnotation(unittest.TestCase):
 
         for m in l.get_matches_for_page(0):
             for bb in m.get_bounding_boxes():
-                doc.get_page(0).append_underline_annotation(
-                    bb.grow(Decimal(2)),
-                    stroke_color=HexColor("DE6449"),
+                doc.get_page(0).append_annotation(
+                    UnderlineAnnotation(
+                        bb.grow(Decimal(2)),
+                        stroke_color=HexColor("DE6449"),
+                    )
                 )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_002.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, doc)
-
-        compare_visually_to_ground_truth(self.output_dir / "output_002.pdf")
+        compare_visually_to_ground_truth(out_file)
+        check_pdf_using_validator(out_file)
