@@ -2,7 +2,7 @@ import cProfile
 import typing
 from pathlib import Path
 
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.pdf import PDF
 
 
