@@ -9,13 +9,20 @@ from borb.pdf.canvas.layout.table.fixed_column_width_table import (
     FixedColumnWidthTable as Table,
 )
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
 from borb.toolkit.text.stop_words import ENGLISH_STOP_WORDS
 from borb.toolkit.text.text_rank_keyword_extraction import TextRankKeywordExtraction
 from borb.toolkit.text.tf_idf_keyword_extraction import TFIDFKeywordExtraction
 
+import nltk
+
+from tests.test_util import check_pdf_using_validator
+
+nltk.download("punkt")
+nltk.download("averaged_perceptron_tagger")
+
 unittest.TestLoader.sortTestMethodsUsing = None
 
 
@@ -90,8 +97,10 @@ class TestExtractKeywords(unittest.TestCase):
         )
 
         # attempt to store PDF
-        with open(self.output_dir / "output_001.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_001.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_extract_keywords_using_tf_idf_from_document(self):
 
@@ -132,8 +141,10 @@ class TestExtractKeywords(unittest.TestCase):
         layout.add(ul)
 
         # attempt to store PDF
-        with open(self.output_dir / "output_002.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_002.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
     def test_extract_keywords_using_textrank_from_document(self):
 
@@ -174,8 +185,10 @@ class TestExtractKeywords(unittest.TestCase):
         layout.add(ul)
 
         # attempt to store PDF
-        with open(self.output_dir / "output_003.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output_003.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, pdf)
+        check_pdf_using_validator(out_file)
 
 
 if __name__ == "__main__":
