@@ -14,7 +14,7 @@ from borb.pdf.canvas.layout.page_layout.page_layout import PageLayout
 from borb.pdf.canvas.layout.table.fixed_column_width_table import FixedColumnWidthTable
 from borb.pdf.canvas.layout.table.table import Table, TableCell
 from borb.pdf.canvas.layout.text.paragraph import Paragraph
-from borb.pdf.document import Document
+from borb.pdf.document.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
 from borb.toolkit.location.location_filter import LocationFilter
@@ -23,6 +23,7 @@ from borb.toolkit.text.regular_expression_text_extraction import (
     PDFMatch,
 )
 from borb.toolkit.text.simple_text_extraction import SimpleTextExtraction
+from tests.test_util import check_pdf_using_validator
 
 unittest.TestLoader.sortTestMethodsUsing = None
 
@@ -281,12 +282,14 @@ class TestExtractTextFromSelfMadeInvoice(unittest.TestCase):
         )
 
         # store
-        with open(self.output_dir / "output.pdf", "wb") as out_file_handle:
+        out_file: Path = self.output_dir / "output.pdf"
+        with open(out_file, "wb") as out_file_handle:
             PDF.dumps(out_file_handle, doc)
+        check_pdf_using_validator(out_file)
 
     def test_extract_text(self):
 
-        r: Rectangle = Rectangle(Decimal(280), Decimal(500), Decimal(200), Decimal(130))
+        r: Rectangle = Rectangle(Decimal(280), Decimal(490), Decimal(200), Decimal(140))
         l0: LocationFilter = LocationFilter(r)
         l1: SimpleTextExtraction = SimpleTextExtraction()
         l0.add_listener(l1)
@@ -299,8 +302,9 @@ class TestExtractTextFromSelfMadeInvoice(unittest.TestCase):
         assert d is not None
 
         # check text
+        txt: str = l1.get_text_for_page(0)
         assert (
-            l1.get_text_for_page(0)
+            txt
             == "SHIP TO\n[Recipient Name]\n[Company Name]\n[Street Address]\n[City, State, ZIP Code]\n[Phone]"
         )
 
@@ -320,7 +324,7 @@ class TestExtractTextFromSelfMadeInvoice(unittest.TestCase):
         r: Rectangle = matches[0].get_bounding_boxes()[0]
 
         assert 298 <= r.get_x() <= 301
-        assert 594 <= r.get_y() <= 596
+        assert 584 <= r.get_y() <= 586
 
     def test_match_regular_expression_use_location(self):
 
